==> zio-aws-ec2_2.13-5.17.102.8-sources.jar: zio/aws/ec2/model/TargetCapacitySpecificationRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class TargetCapacitySpecificationRequest(
    totalTargetCapacity: Integer,
    onDemandTargetCapacity: Option[Integer] = None,
    spotTargetCapacity: Option[Integer] = None,
    defaultTargetCapacityType: Option[
      zio.aws.ec2.model.DefaultTargetCapacityType
    ] = None,
    targetCapacityUnitType: Option[zio.aws.ec2.model.TargetCapacityUnitType] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.TargetCapacitySpecificationRequest = {
    import TargetCapacitySpecificationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.TargetCapacitySpecificationRequest
      .builder()
      .totalTargetCapacity(
        Integer.unwrap(totalTargetCapacity): java.lang.Integer
      )
      .optionallyWith(
        onDemandTargetCapacity.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.onDemandTargetCapacity)
      .optionallyWith(
        spotTargetCapacity.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.spotTargetCapacity)
      .optionallyWith(defaultTargetCapacityType.map(value => value.unwrap))(
        _.defaultTargetCapacityType
      )
      .optionallyWith(targetCapacityUnitType.map(value => value.unwrap))(
        _.targetCapacityUnitType
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.TargetCapacitySpecificationRequest.ReadOnly =
    zio.aws.ec2.model.TargetCapacitySpecificationRequest.wrap(buildAwsValue())
}
object TargetCapacitySpecificationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.TargetCapacitySpecificationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.TargetCapacitySpecificationRequest =
      zio.aws.ec2.model.TargetCapacitySpecificationRequest(
        totalTargetCapacity,
        onDemandTargetCapacity.map(value => value),
        spotTargetCapacity.map(value => value),
        defaultTargetCapacityType.map(value => value),
        targetCapacityUnitType.map(value => value)
      )
    def totalTargetCapacity: Integer
    def onDemandTargetCapacity: Option[Integer]
    def spotTargetCapacity: Option[Integer]
    def defaultTargetCapacityType
        : Option[zio.aws.ec2.model.DefaultTargetCapacityType]
    def targetCapacityUnitType: Option[zio.aws.ec2.model.TargetCapacityUnitType]
    def getTotalTargetCapacity: ZIO[Any, Nothing, Integer] =
      ZIO.succeed(totalTargetCapacity)
    def getOnDemandTargetCapacity: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("onDemandTargetCapacity", onDemandTargetCapacity)
    def getSpotTargetCapacity: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("spotTargetCapacity", spotTargetCapacity)
    def getDefaultTargetCapacityType
        : ZIO[Any, AwsError, zio.aws.ec2.model.DefaultTargetCapacityType] =
      AwsError.unwrapOptionField(
        "defaultTargetCapacityType",
        defaultTargetCapacityType
      )
    def getTargetCapacityUnitType
        : ZIO[Any, AwsError, zio.aws.ec2.model.TargetCapacityUnitType] =
      AwsError.unwrapOptionField(
        "targetCapacityUnitType",
        targetCapacityUnitType
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.TargetCapacitySpecificationRequest
  ) extends zio.aws.ec2.model.TargetCapacitySpecificationRequest.ReadOnly {
    override val totalTargetCapacity: Integer =
      zio.aws.ec2.model.primitives.Integer(impl.totalTargetCapacity())
    override val onDemandTargetCapacity: Option[Integer] = scala
      .Option(impl.onDemandTargetCapacity())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val spotTargetCapacity: Option[Integer] = scala
      .Option(impl.spotTargetCapacity())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val defaultTargetCapacityType
        : Option[zio.aws.ec2.model.DefaultTargetCapacityType] = scala
      .Option(impl.defaultTargetCapacityType())
      .map(value => zio.aws.ec2.model.DefaultTargetCapacityType.wrap(value))
    override val targetCapacityUnitType
        : Option[zio.aws.ec2.model.TargetCapacityUnitType] = scala
      .Option(impl.targetCapacityUnitType())
      .map(value => zio.aws.ec2.model.TargetCapacityUnitType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.TargetCapacitySpecificationRequest
  ): zio.aws.ec2.model.TargetCapacitySpecificationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.151.2-sources.jar: zio/aws/ec2/model/TargetCapacitySpecificationRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class TargetCapacitySpecificationRequest(
    totalTargetCapacity: Integer,
    onDemandTargetCapacity: Option[Integer] = None,
    spotTargetCapacity: Option[Integer] = None,
    defaultTargetCapacityType: Option[
      zio.aws.ec2.model.DefaultTargetCapacityType
    ] = None,
    targetCapacityUnitType: Option[zio.aws.ec2.model.TargetCapacityUnitType] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.TargetCapacitySpecificationRequest = {
    import TargetCapacitySpecificationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.TargetCapacitySpecificationRequest
      .builder()
      .totalTargetCapacity(totalTargetCapacity: java.lang.Integer)
      .optionallyWith(
        onDemandTargetCapacity.map(value => value: java.lang.Integer)
      )(_.onDemandTargetCapacity)
      .optionallyWith(
        spotTargetCapacity.map(value => value: java.lang.Integer)
      )(_.spotTargetCapacity)
      .optionallyWith(defaultTargetCapacityType.map(value => value.unwrap))(
        _.defaultTargetCapacityType
      )
      .optionallyWith(targetCapacityUnitType.map(value => value.unwrap))(
        _.targetCapacityUnitType
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.TargetCapacitySpecificationRequest.ReadOnly =
    zio.aws.ec2.model.TargetCapacitySpecificationRequest.wrap(buildAwsValue())
}
object TargetCapacitySpecificationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.TargetCapacitySpecificationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.TargetCapacitySpecificationRequest =
      zio.aws.ec2.model.TargetCapacitySpecificationRequest(
        totalTargetCapacity,
        onDemandTargetCapacity.map(value => value),
        spotTargetCapacity.map(value => value),
        defaultTargetCapacityType.map(value => value),
        targetCapacityUnitType.map(value => value)
      )
    def totalTargetCapacity: Integer
    def onDemandTargetCapacity: Option[Integer]
    def spotTargetCapacity: Option[Integer]
    def defaultTargetCapacityType
        : Option[zio.aws.ec2.model.DefaultTargetCapacityType]
    def targetCapacityUnitType: Option[zio.aws.ec2.model.TargetCapacityUnitType]
    def getTotalTargetCapacity: ZIO[Any, Nothing, Integer] =
      ZIO.succeed(totalTargetCapacity)
    def getOnDemandTargetCapacity: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("onDemandTargetCapacity", onDemandTargetCapacity)
    def getSpotTargetCapacity: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("spotTargetCapacity", spotTargetCapacity)
    def getDefaultTargetCapacityType
        : ZIO[Any, AwsError, zio.aws.ec2.model.DefaultTargetCapacityType] =
      AwsError.unwrapOptionField(
        "defaultTargetCapacityType",
        defaultTargetCapacityType
      )
    def getTargetCapacityUnitType
        : ZIO[Any, AwsError, zio.aws.ec2.model.TargetCapacityUnitType] =
      AwsError.unwrapOptionField(
        "targetCapacityUnitType",
        targetCapacityUnitType
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.TargetCapacitySpecificationRequest
  ) extends zio.aws.ec2.model.TargetCapacitySpecificationRequest.ReadOnly {
    override val totalTargetCapacity: Integer =
      impl.totalTargetCapacity(): Integer
    override val onDemandTargetCapacity: Option[Integer] =
      scala.Option(impl.onDemandTargetCapacity()).map(value => value: Integer)
    override val spotTargetCapacity: Option[Integer] =
      scala.Option(impl.spotTargetCapacity()).map(value => value: Integer)
    override val defaultTargetCapacityType
        : Option[zio.aws.ec2.model.DefaultTargetCapacityType] = scala
      .Option(impl.defaultTargetCapacityType())
      .map(value => zio.aws.ec2.model.DefaultTargetCapacityType.wrap(value))
    override val targetCapacityUnitType
        : Option[zio.aws.ec2.model.TargetCapacityUnitType] = scala
      .Option(impl.targetCapacityUnitType())
      .map(value => zio.aws.ec2.model.TargetCapacityUnitType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.TargetCapacitySpecificationRequest
  ): zio.aws.ec2.model.TargetCapacitySpecificationRequest.ReadOnly =
    new Wrapper(impl)
}
